#!/bin/bash

CMDPARA=$1
INSTDIR="$( cd "$( dirname "${BASH_SOURCE[0]}" )" >/dev/null 2>&1 && pwd )"

CMD=`basename $0`
[[ "$CMD" == "run_brokerconfig.sh" ]] && CMDPARA=config

PROCPATTERN="$INSTDIR/OpenLM[B]roker.jar"
PROCS="`ps -def|grep $PROCPATTERN|grep -v grep|awk '{print $2}'|tr -d '^J'`"

source $INSTDIR/settings.sh
ISBROKERACTIVE="$(systemctl is-active "$BROKERSRVNAME")"
#check if service is installed
if [[ ("$ISBROKERACTIVE" == "unknown" || "$ISBROKERACTIVE" == "inactive") && ("$CMDPARA" != "install") ]]
  then
    echo "OpenLM Broker Service is not installed!"
    exit
fi

if [ ! -d "$JAVA_HOME" ]; then
  echo "ERROR no JRE found"
  exit 2
else
  if [ ! -x "$JAVA_HOME/bin/java" ]; then
    echo "ERROR no JRE found"
    exit 3
  else
    if [ ! -d "$INSTDIR" ]; then
      echo "ERROR Broker directory not found"
      exit 4
    fi
    cd $INSTDIR
    case $CMDPARA in
    install)
      ./install_broker.sh
      ;;
    uninstall)
      ./uninstall_broker.sh
      ;;
    config)
      "$JAVA_HOME/bin/java" -Djava.net.preferIPv4Stack=true -jar "$INSTDIR/BrokerConfigurator.jar" broker.xml
      ;;
    stop)
      if [ "$PROCS" ];then
        service $BROKERSRVNAME stop
	echo "Broker service is stopped (PID: $PROCS)"
      else
        echo "Broker service is not running!"
      fi
      exit $RES
      ;;
    restart)
      service $BROKERSRVNAME restart
      echo "Broker service is restarted"
      ;;
    status)
      #if [ -n "`ps -def|awk "/OpenLM[B]roker/ {print $2}'`" ]; then
      if [ -n "$PROCS" ]; then
        echo -e "\e[92mBroker service is running (PID: $PROCS)!\033[0m"
      else
        echo -e "\e[91mBroker service is not running!\033[0m"
      fi
      ;;
    start)
      if [ -z "$PROCS" ];then
        service $BROKERSRVNAME start
      else
        echo "Broker service is already running (PID: $PROCS)"
        exit 5
      fi
      ;;
    *)
      echo -e "\e[96mUsage: $CMD [start|stop|restart|status|config|install|uninstall]\033[0m"
      exit
    esac
  fi
fi
