#################################################################################
#						Spec file for OpenLM Broker								#
#################################################################################
# Configured to be built by user openlm or non root user with sudo permission	#
#################################################################################

Summary: Broker by OpenLM
Name: openlm_broker
Version: {{version}}
Release: {{release}}
AutoReqProv: no
License: GPL
URL: http://www.openlm.com
Group: System
Packager: {{Packager}}
Requires: /bin/sh,java,systemd

# Build with the following syntax:
# rpmbuild --target noarch -bb utils.spec

%description
This package contain the Openlm broker. This application report the linces activity of license manager to the Openlm Server.

%prep
#################################################################################
# Create the build tree and copy the files from the development directories    	#
# into the build tree.                                                         	#
#################################################################################
echo "BUILDROOT = $RPM_BUILD_ROOT"
mkdir -p $RPM_BUILD_ROOT/opt/broker
mkdir -p $RPM_BUILD_ROOT/etc/systemd/system

mv $RPM_BUILD_ROOT/SOURCES/* $RPM_BUILD_ROOT/opt/broker
mv $RPM_BUILD_ROOT/opt/broker/broker.service $RPM_BUILD_ROOT/etc/systemd/system/broker.service

exit

%files
#################################################################################
#	 Specify which files should deployes with this format               	#
# 		(Chmod, user, group) Path                                 	#
#################################################################################
%config /opt/broker/settings.sh
%config /etc/systemd/system/broker.service
%attr(0744, openlm, openlm) /opt/broker/*
%attr(0755, openlm, openlm) /opt/broker/*.sh
%attr(0644, root, root) /etc/systemd/system/broker.service

%pre
#################################################################################
# 	Command to run before copying the files in the installation server    #
# 			this require sudo permission                      #
#################################################################################

if [ $1 == 1 ];then
  echo "RPM is getting installed"

  user="openlm" && echo "Application user : $user"
  group="openlm" && echo "Application group : $group"
  password=$(perl -e 'print crypt($ARGV[0], "password")' "$(date | md5sum)")

  #Check if openlm group exist
  echo "Check for $group group"
  
  if [ $(getent group $group) ];then 
      echo "$group Group already exist, Group ID : $(id -g $group)"
  else 
    groupadd $group -f && echo "group $group added"	
  fi

  #Check if openlm user exist
  echo "Check for $user User"
  if [ "$(getent passwd $user)" ];then 
    echo "$user user already exist, User ID : $(id -u $user)"
  else 
    useradd -m -r -g $group $user -p $password -c "$user user for OpenLM application" && echo "The password for the new $user user is : $password"
  fi
fi

if [ $1 == 2 ];then
  echo "RPM is getting upgraded"
fi

echo "Copying files"

%post
#################################################################################
# 		Action to do after the installation                        	#
#################################################################################

#reload the service daemon management to handle the new service
if [ $1 == 1 ];then
#Edit the settings file
    javalocation=`dirname $(dirname $(which java))`
    sed -i "s|BROKERSRVNAMEUSER\=.*|BROKERSRVNAMEUSER=\"openlm\"|g" /opt/broker/settings.sh
    sed -i "s|BROKERSRVNAME\=.*|BROKERSRVNAME=\"broker\"|g" /opt/broker/settings.sh
    sed -i "s|JAVA_HOME\=.*|JAVA_HOME=$javalocation|g" /opt/broker/settings.sh

#Handle Service
  systemctl daemon-reload && echo "systemctl has been reloaded, the new service file is /etc/systemd/system/broker.service"
  systemctl enable broker && echo "service set as restart on failure"
  systemctl reset-failed
  systemctl start broker && echo "broker.service started"
fi

if [ $1 == 2 ];then
  systemctl restart broker && echo "broker.service restarted"
fi

%postun
#################################################################################
# 			Action to do for uninstall   			#
#################################################################################

if [ $1 == 0 ];then
  echo "RPM is getting removed/uninstalled"
  
  systemctl stop broker && echo "broker.service stopped"
  rm -f /etc/systemd/system/broker.service && echo "/etc/systemd/system/broker.service removed"
  rm -rf /opt/broker && echo "/opt/broker removed recursively"
fi

%clean
rm -rf $RPM_BUILD_ROOT
